///////////////////////////////////////////////////////////////////////////////
//
//  Copyright (2008) Alexander Stukowski
//
//  This file is part of OVITO (Open Visualization Tool).
//
//  OVITO is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  OVITO is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

#include <core/Core.h>
#include "InvertSelectionModifier.h"

namespace AtomViz {

IMPLEMENT_SERIALIZABLE_PLUGIN_CLASS(InvertSelectionModifier, AtomsObjectModifierBase)

/******************************************************************************
* This modifies the input object.
******************************************************************************/
EvaluationStatus InvertSelectionModifier::modifyAtomsObject(TimeTicks time, TimeInterval& validityInterval)
{
	// Get the deep copy of the selection channel.
	DataChannel* selChannel = outputStandardChannel(DataChannel::SelectionChannel);

	int* s = selChannel->dataInt();
	int* send = s + selChannel->size();

	// Just invert the selection channel values.
	for(; s != send; ++s)
		*s = !(*s);

	return EvaluationStatus();
}

};	// End of namespace AtomViz
